#ifndef __UNITERM_IOS_MAIN_H__
#define __UNITERM_IOS_MAIN_H__

#import <CoreFoundation/CoreFoundation.h>

#ifdef __cplusplus
extern "C" {
#endif

BOOL uniterm_initialize(void);
BOOL uniterm_reinitialize(void);
BOOL uniterm_modify_config(NSDictionary *req);
NSDictionary *uniterm_run_trans(NSDictionary *req);

/*! Register the mobile application that is using
 * UniTerm for processing.
 *
 * This is optional and used for logging purposes when
 * UniTerm starts. The information will be recoreded
 * in the log and is helpful for diagnostic purposes.
 *
 * UniTerm must be initalized before calling this function.
 */
void uniterm_register_product(NSString *product_name, NSString *product_type,
		NSString *device_id, NSString *device_name,
		NSString *device_manuf, NSString *device_model,
		NSString *device_os, NSString *device_osver,
		NSString *app_ver);

/*! Convert a bitstring to a TIFF image.
 *
 * \param[in] bytes_in       Bytes representing image data in a one bit per pixel
 *                           format with 1 representing white and 0 representing black.
 * \param[in] bytes_in_len   Length of the bytes_in buffer.  This should be equal to
 *                           (image_width * image_height) / 8
 * \param[in] image_width    Width of the image in pixels, images should have a width
 *                           that is a multiple of 8 so the number of bits ends on a
 *                           byte boundary.
 * \param[in] image_height   Height of the image in pixels
 * \param[out] tiff_out_size Size of returned buffer containing a TIFF image.
 * \return Buffer containing a TIFF image or NULL on failure.  Use free() not M_free() to
 *         release this data.
 */
unsigned char *uniterm_bitstring_to_tiffimage(const unsigned char *bytes_in, size_t num_bytes_in, size_t image_width, size_t image_height, size_t *tiff_out_size);


/*! Convert a TIFF image into a 1 bit per pixel bitstring.
 *
 * \param[in]  tiff_in          Bytes representing tiff image data.  Image must already be
 *                              in a 1 bit per pixel format and compressed with deflate.
 * \param[in]  tiff_in_size     Size of tiff_in buffer.
 * \param[out] image_width_out  Width of the image in pixels.
 * \param[out] image_height_out Height of the image in pixels
 * \param[out] out_size         Size of returned buffer containing a 1 bit per pixel bitstring.
 * \return Buffer containing a bitstring or NULL on failure. Use free() not M_free() to
 *         release this data.
 */
unsigned char *uniterm_tiffimage_to_bitstring(const unsigned char *tiff_in, size_t tiff_in_size, size_t *image_width_out, size_t *image_height_out, size_t *out_size);


#ifdef __cplusplus
};
#endif

#endif /* __UNITERM_IOS_MAIN_H__ */

